@@ -15,6 +15,7 @@ G_BEGIN_DECLS
  * RetroRumbleEffect:
  * @RETRO_RUMBLE_EFFECT_STRONG: the strong rumble effect
  * @RETRO_RUMBLE_EFFECT_WEAK: the weak rumble effect
+ * @RETRO_RUMBLE_EFFECT_COUNT: the number of rumble effects
  *
  * Represents the strength of the rumble effect.
  */
@@ -22,6 +23,7 @@ typedef enum
 {
   RETRO_RUMBLE_EFFECT_STRONG,
   RETRO_RUMBLE_EFFECT_WEAK,
+  RETRO_RUMBLE_EFFECT_COUNT,
 } RetroRumbleEffect;
 
 G_END_DECLS
